@@ -26,7 +26,6 @@
 #include "skgbankgui_export.h"
 
 #include <QWidget>
-#include <QtDesigner/QDesignerExportWidget>
 
 class SKGDocument;
 
@@ -57,7 +56,7 @@ public:
      * @param iListAttribute the list of attribute (empty means all attributes supported of the table)
      * @param iModeUpdate to enable update mode
      */
-    virtual void setParameters(SKGDocument* iDocument, const QString& iTable, const QStringList& iListAttribute=QStringList(), bool iModeUpdate=false);
+    virtual void setParameters(SKGDocument* iDocument, const QString& iTable, const QStringList& iListAttribute = QStringList(), bool iModeUpdate = false);
 
     /**
      * Set XML representing the query
@@ -71,28 +70,28 @@ public:
      */
     virtual QString getXMLCondition();
 
-public slots:
+public Q_SLOTS:
     /**
      * Clear table content
      */
     void clearContents();
 
-private slots:
-    void onRemoveLine(int iRow=-1);
-    void onRemoveColumn(int iColumn=-1);
+private Q_SLOTS:
+    void onRemoveLine(int iRow = -1);
+    void onRemoveColumn(int iColumn = -1);
     void onCloseEditor();
     void onAddColumn();
 private:
     Q_DISABLE_COPY(SKGQueryCreator);
 
     void addNewLine();
-    int getIndexQueryColumn(const QString& iAttribute, int row=-1);
+    int getIndexQueryColumn(const QString& iAttribute, int row = -1);
     void addColumnFromAttribut(const QListWidgetItem* listItem);
 
     Ui::skgquerycreator_base ui;
-    SKGDocument* document;
-    QString table;
-    bool updateMode;
+    SKGDocument* m_document;
+    QString m_table;
+    bool m_updateMode;
 };
 
 #endif // SKGQUERYCREATOR_H
