@@ -25,7 +25,7 @@
 
 #include <klocale.h>
 
-SKGBankObject::SKGBankObject(const SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, "v_bank", iID)
+SKGBankObject::SKGBankObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, "v_bank", iID)
 {
 }
 
@@ -34,57 +34,75 @@ SKGBankObject::~SKGBankObject()
 }
 
 SKGBankObject::SKGBankObject(const SKGBankObject& iObject)
-                :SKGNamedObject(iObject)
+    : SKGNamedObject(iObject)
 {
 }
 
-const SKGBankObject& SKGBankObject::operator= (const SKGObjectBase& iObject)
+SKGBankObject::SKGBankObject(const SKGNamedObject& iObject)
 {
+    if(iObject.getRealTable() == "bank") {
         copyFrom(iObject);
-        return *this;
+    } else {
+        *this = SKGNamedObject(iObject.getDocument(), "v_bank", iObject.getID());
+    }
+}
+
+SKGBankObject::SKGBankObject(const SKGObjectBase& iObject)
+{
+    if(iObject.getRealTable() == "bank") {
+        copyFrom(iObject);
+    } else {
+        *this = SKGNamedObject(iObject.getDocument(), "v_bank", iObject.getID());
+    }
+}
+
+const SKGBankObject& SKGBankObject::operator= (const SKGObjectBase & iObject)
+{
+    copyFrom(iObject);
+    return *this;
 }
 
 SKGError SKGBankObject::addAccount(SKGAccountObject& oAccount)
 {
-        SKGError err;
-        if (getID() == 0) err=SKGError(ERR_FAIL, i18n("%1 failed because linked object is not yet saved in the database.",QString("SKGBankObject::addAccount")));
-        else {
-                oAccount = SKGAccountObject((SKGDocumentBank*) getDocument());
-                err = oAccount.setAttribute("rd_bank_id", SKGServices::intToString(getID()));
-        }
-        return err;
+    SKGError err;
+    if(getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QString("SKGBankObject::addAccount")));
+    else {
+        oAccount = SKGAccountObject(static_cast<SKGDocumentBank*>(getDocument()));
+        err = oAccount.setAttribute("rd_bank_id", SKGServices::intToString(getID()));
+    }
+    return err;
 }
 
 SKGError SKGBankObject::getAccounts(SKGListSKGObjectBase& oAccountList) const
 {
-        SKGError err = getObjects(getDocument(), "v_account",
-                                  "rd_bank_id=" + SKGServices::intToString(getID()),
-                                  oAccountList);
-        return err;
+    SKGError err = getDocument()->getObjects("v_account",
+                   "rd_bank_id=" + SKGServices::intToString(getID()),
+                   oAccountList);
+    return err;
 }
 
 SKGError SKGBankObject::setNumber(const QString& iNumber)
 {
-        return setAttribute("t_bank_number", iNumber);
+    return setAttribute("t_bank_number", iNumber);
 }
 
 QString SKGBankObject::getNumber() const
 {
-        return getAttribute("t_bank_number");
+    return getAttribute("t_bank_number");
 }
 
 SKGError SKGBankObject::setIcon(const QString& iIcon)
 {
-        return setAttribute("t_icon", iIcon);
+    return setAttribute("t_icon", iIcon);
 }
 
 QString SKGBankObject::getIcon() const
 {
-        return getAttribute("t_icon");
+    return getAttribute("t_icon");
 }
 
 double SKGBankObject::getCurrentAmount() const
 {
-        return SKGServices::stringToDouble(getAttribute("f_CURRENTAMOUNT"));
+    return SKGServices::stringToDouble(getAttribute("f_CURRENTAMOUNT"));
 }
 #include "skgbankobject.moc"
