@@ -35,7 +35,7 @@ class SKGUnitValueObject;
 class SKGBANKMODELER_EXPORT SKGDocumentBank : public SKGDocument
 {
     Q_OBJECT;
-    Q_CLASSINFO("D-Bus Interface", "org.skrooge.SKGDocumentBank")
+    Q_CLASSINFO("D-Bus Interface", "org.skrooge.SKGDocumentBank");
 
 public:
     /**
@@ -48,7 +48,7 @@ public:
     */
     virtual ~SKGDocumentBank();
 
-public slots:
+public Q_SLOTS:
     /**
      * Close the current transaction.
      * A transaction is needed to modify the SKGDocument.
@@ -83,23 +83,6 @@ public slots:
      */
     virtual SKGError addOrModifyAccount(const QString& iName, const QString& iNumber, const QString& iBankName);
 
-    /**
-     * Rename an ccount
-     * @param iName account name
-     * @param inewName new account name
-     * @return an object managing the error.
-     *   @see SKGError
-     */
-    virtual SKGError RenameAccount(const QString& iName, const QString& inewName);
-
-    /**
-     * delete an account
-     * @param iName account name
-     * @return an object managing the error.
-     *   @see SKGError
-     */
-    virtual SKGError deleteAccount(const QString& iName);
-
     /**
      * Create or modify the value of an unit
      * @param iUnitName unit name
@@ -109,33 +92,7 @@ public slots:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError addOrModifyUnitValue(const QString& iUnitName, const QDate& iDate, double iValue, SKGUnitValueObject* oValue=NULL);
-
-    /**
-     * Update unit's attributes
-     * @param iUnitName unit name
-     * @param iInternetCode new Internet code
-     * @return an object managing the error.
-     *   @see SKGError
-     */
-    virtual SKGError ModifyUnit(const QString& iUnitName, const QString& iInternetCode);
-
-    /**
-     * Rename a unit
-     * @param iUnitName old name of the unit
-     * @param inewName new name of the unit
-     * @return an object managing the error.
-     *   @see SKGError
-     */
-    virtual SKGError RenameUnit(const QString& iUnitName, const QString& inewName);
-
-    /**
-     * Delete a unit
-     * @param iUnitName unitname
-     * @return an object managing the error.
-     *   @see SKGError
-     */
-    virtual SKGError deleteUnit(const QString& iUnitName);
+    virtual SKGError addOrModifyUnitValue(const QString& iUnitName, const QDate& iDate, double iValue, SKGUnitValueObject* oValue = NULL);
 
     /**
      * Get formated money
@@ -191,6 +148,13 @@ public slots:
      */
     virtual QString getDisplay(const QString& iString) const;
 
+    /**
+     * Get the real attribute
+     * @param iString the name of the attribute (something like t_BANK)
+     * @return the real attribute (something like bank.rd_bank_id.t_name)
+     */
+    virtual QString getRealAttribute(const QString& iString) const;
+
     /**
      * Get the icon for attribute
      * @param iString the name of the attribute
@@ -217,6 +181,40 @@ public slots:
      */
     virtual QString getDocumentHeader() const;
 
+    /**
+     * Get budget report
+     * @param iMonth the month
+     * @return the html report
+     */
+    virtual QString getBudget(const QString& iMonth);
+
+    /**
+     * Get 5 main category report
+     * @param iMonth the month
+     * @param iChart to add chart
+     * @return the html report
+     */
+    virtual QString get5MainCategories(const QString& iMonth, bool iChart = true);
+
+    /**
+     * Get 5 main variation of categories report
+     * @param iMonth the month
+     * @param iPreviousMonth the previous month
+     * @param iOnlyIssues only "Expenses increased" and "Incomes decreased"
+     * @param oCategoryList to get the category for each variation
+     * @return the list of variation string
+     */
+    QStringList get5MainCategoriesVariationList(const QString& iMonth, const QString& iPreviousMonth, bool iOnlyIssues = false, QStringList* oCategoryList = NULL);
+
+    /**
+     * Get 5 main variation of categories report
+     * @param iMonth the month
+     * @param iPreviousMonth the previous month
+     * @param iOnlyIssues only "Expenses increased" and "Incomes decreased"
+     * @return the html report
+     */
+    QString get5MainCategoriesVariation(const QString& iMonth, const QString& iPreviousMonth, bool iOnlyIssues = false);
+
 protected:
     /**
      * Get impacted tables if one object of @p iTable is modifier.
@@ -235,13 +233,27 @@ protected:
      */
     virtual SKGError migrate(bool& oMigrationDone);
 
+    /**
+     * Compute balance of each operation.
+     * @return an object managing the error.
+     *   @see SKGError
+     */
+    virtual SKGError computeBalances();
+    /**
+     * Compute the budgets categories links.
+     * @return an object managing the error.
+     *   @see SKGError
+     */
+    virtual SKGError computeBudgetCategoriesLinks();
 
-private slots:
+private Q_SLOTS:
     virtual void refreshCache(const QString& iTable);
 
 private:
     Q_DISABLE_COPY(SKGDocumentBank);
+
+    QString m_5mainVariations_inputs;
+    QStringList m_5mainVariations_cache;
+    QStringList m_5mainVariationsCat_cache;
 };
-
-
 #endif
