@@ -43,7 +43,7 @@ public:
     /**
      * This enumerate defines how to compute value date
      */
-    enum ValueDateMode {FIFTEEN=0,
+    enum ValueDateMode {FIFTEEN = 0,
                         J0,
                         J1,
                         J2,
@@ -55,7 +55,7 @@ public:
     /**
      * This enumerate defines how to compute interest
      */
-    enum InterestMode {FIFTEEN24=0,
+    enum InterestMode {FIFTEEN24 = 0,
                        DAYS360,
                        DAYS365
                       };
@@ -65,7 +65,7 @@ public:
      * @param iDocument the document containing the object
      * @param iID the identifier in @p iTable of the object
      */
-    explicit SKGInterestObject(SKGDocument* iDocument=NULL, int iID=0);
+    explicit SKGInterestObject(SKGDocument* iDocument = NULL, int iID = 0);
 
     /**
      * Copy constructor
@@ -184,5 +184,8 @@ protected:
      */
     virtual QString getWhereclauseId() const;
 };
-
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO(SKGInterestObject, Q_MOVABLE_TYPE);
 #endif
