@@ -23,7 +23,7 @@
 #include "skgoperationobject.h"
 #include "skgsuboperationobject.h"
 #include "skgservices.h"
-#include "skgdocument.h"
+#include "skgdocumentbank.h"
 #include "skgtraces.h"
 
 #include <klocale.h>
@@ -37,20 +37,20 @@ SKGRecurrentOperationObject::~SKGRecurrentOperationObject()
 }
 
 SKGRecurrentOperationObject::SKGRecurrentOperationObject(const SKGRecurrentOperationObject& iObject)
-        : SKGObjectBase(iObject)
+    : SKGObjectBase(iObject)
 {
 }
 
 SKGRecurrentOperationObject::SKGRecurrentOperationObject(const SKGObjectBase& iObject)
 {
-    if (iObject.getRealTable()=="recurrentoperation") {
+    if(iObject.getRealTable() == "recurrentoperation") {
         copyFrom(iObject);
     } else {
-        *this=SKGObjectBase(iObject.getDocument(), "v_recurrentoperation", iObject.getID());
+        *this = SKGObjectBase(iObject.getDocument(), "v_recurrentoperation", iObject.getID());
     }
 }
 
-const SKGRecurrentOperationObject& SKGRecurrentOperationObject::operator= (const SKGObjectBase& iObject)
+const SKGRecurrentOperationObject& SKGRecurrentOperationObject::operator= (const SKGObjectBase & iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -59,8 +59,8 @@ const SKGRecurrentOperationObject& SKGRecurrentOperationObject::operator= (const
 SKGError SKGRecurrentOperationObject::getParentOperation(SKGOperationObject& oOperation) const
 {
     SKGObjectBase objTmp;
-    SKGError err = getObject(getDocument(), "v_operation", "id=" + getAttribute("rd_operation_id"), objTmp);
-    oOperation=objTmp;
+    SKGError err = getDocument()->getObject("v_operation", "id=" + getAttribute("rd_operation_id"), objTmp);
+    oOperation = objTmp;
     return err;
 }
 
@@ -81,15 +81,15 @@ int SKGRecurrentOperationObject::getPeriodIncrement() const
 
 SKGRecurrentOperationObject::PeriodUnit SKGRecurrentOperationObject::getPeriodUnit() const
 {
-    QString t_period_unit=getAttribute("t_period_unit");
-    if (t_period_unit=="D") return SKGRecurrentOperationObject::DAY;
-    else if (t_period_unit=="M") return SKGRecurrentOperationObject::MONTH;
+    QString t_period_unit = getAttribute("t_period_unit");
+    if(t_period_unit == "D") return SKGRecurrentOperationObject::DAY;
+    else if(t_period_unit == "M") return SKGRecurrentOperationObject::MONTH;
     return SKGRecurrentOperationObject::YEAR;
 }
 
 SKGError SKGRecurrentOperationObject::setPeriodUnit(SKGRecurrentOperationObject::PeriodUnit iPeriod)
 {
-    return setAttribute("t_period_unit", (iPeriod==SKGRecurrentOperationObject::DAY ? "D" : (iPeriod==SKGRecurrentOperationObject::MONTH ? "M" : "Y")));
+    return setAttribute("t_period_unit", (iPeriod == SKGRecurrentOperationObject::DAY ? "D" : (iPeriod == SKGRecurrentOperationObject::MONTH ? "M" : "Y")));
 }
 
 SKGError SKGRecurrentOperationObject::setAutoWriteDays(int iDays)
@@ -114,32 +114,30 @@ int SKGRecurrentOperationObject::getWarnDays() const
 
 bool SKGRecurrentOperationObject::hasTimeLimit() const
 {
-    return (getAttribute("t_times")=="Y" ? true : false);
+    return (getAttribute("t_times") == "Y" ? true : false);
 }
 
 SKGError SKGRecurrentOperationObject::timeLimit(bool iTimeLimit)
 {
-    return setAttribute("t_times", iTimeLimit ? "Y" :"N");
+    return setAttribute("t_times", iTimeLimit ? "Y" : "N");
 }
 
 SKGError SKGRecurrentOperationObject::setTimeLimit(const QDate& iLastDate)
 {
     //Get parameters
-    QDate firstDate=this->getDate();
-    SKGRecurrentOperationObject::PeriodUnit period=this->getPeriodUnit();
-    int occu=this->getPeriodIncrement();
+    QDate firstDate = this->getDate();
+    SKGRecurrentOperationObject::PeriodUnit period = this->getPeriodUnit();
+    int occu = this->getPeriodIncrement();
 
     //Compute nb time
-    int nbd=firstDate.daysTo ( iLastDate );
-    if ( period==SKGRecurrentOperationObject::DAY ) nbd=nbd/occu;
-    else if ( period==SKGRecurrentOperationObject::MONTH )
-    {
-        nbd= ( iLastDate.day() >=firstDate.day() ? 0 : -1 ) + ( iLastDate.year()-firstDate.year() ) *12+ ( iLastDate.month()-firstDate.month() );
-    }
-    else if ( period==SKGRecurrentOperationObject::YEAR ) nbd=nbd/ ( 365*occu );
+    int nbd = firstDate.daysTo(iLastDate);
+    if(period == SKGRecurrentOperationObject::DAY) nbd = nbd / occu;
+    else if(period == SKGRecurrentOperationObject::MONTH) {
+        nbd = (iLastDate.day() >= firstDate.day() ? 0 : -1) + (iLastDate.year() - firstDate.year()) * 12 + (iLastDate.month() - firstDate.month());
+    } else if(period == SKGRecurrentOperationObject::YEAR) nbd = nbd / (365 * occu);
 
-    if ( nbd<-1 ) nbd=-1;
-    return setTimeLimit ( nbd+1 );
+    if(nbd < -1) nbd = -1;
+    return setTimeLimit(nbd + 1);
 }
 
 SKGError SKGRecurrentOperationObject::setTimeLimit(int iTimeLimit)
@@ -158,12 +156,12 @@ SKGError SKGRecurrentOperationObject::setDate(const QDate& iDate)
 
 QDate SKGRecurrentOperationObject::getNextDate() const
 {
-    QDate nextDate=getDate();
-    SKGRecurrentOperationObject::PeriodUnit punit=getPeriodUnit();
-    int p=getPeriodIncrement();
-    if (punit==SKGRecurrentOperationObject::DAY) nextDate=nextDate.addDays(p);
-    else if (punit==SKGRecurrentOperationObject::MONTH) nextDate=nextDate.addMonths(p);
-    else if (punit==SKGRecurrentOperationObject::YEAR) nextDate=nextDate.addYears(p);
+    QDate nextDate = getDate();
+    SKGRecurrentOperationObject::PeriodUnit punit = getPeriodUnit();
+    int p = getPeriodIncrement();
+    if(punit == SKGRecurrentOperationObject::DAY) nextDate = nextDate.addDays(p);
+    else if(punit == SKGRecurrentOperationObject::MONTH) nextDate = nextDate.addMonths(p);
+    else if(punit == SKGRecurrentOperationObject::YEAR) nextDate = nextDate.addYears(p);
     return nextDate;
 }
 
@@ -174,89 +172,89 @@ QDate SKGRecurrentOperationObject::getDate() const
 
 SKGError SKGRecurrentOperationObject::warnEnabled(bool iWarn)
 {
-    return setAttribute("t_warn", iWarn ? "Y" :"N");
+    return setAttribute("t_warn", iWarn ? "Y" : "N");
 }
 
 bool SKGRecurrentOperationObject::isWarnEnabled() const
 {
-    return (getAttribute("t_warn")=="Y" ? true : false);
+    return (getAttribute("t_warn") == "Y" ? true : false);
 }
 
 SKGError SKGRecurrentOperationObject::autoWriteEnabled(bool iAutoWrite)
 {
-    return setAttribute("t_auto_write", iAutoWrite ? "Y" :"N");
+    return setAttribute("t_auto_write", iAutoWrite ? "Y" : "N");
 
 }
 
 bool SKGRecurrentOperationObject::isAutoWriteEnabled() const
 {
-    return (getAttribute("t_auto_write")=="Y" ? true : false);
+    return (getAttribute("t_auto_write") == "Y" ? true : false);
 }
 
 SKGError SKGRecurrentOperationObject::getRecurredOperations(SKGListSKGObjectBase& oOperations) const
 {
-    return SKGObjectBase::getObjects(getDocument(), "v_operation", "r_recurrentoperation_id="+ SKGServices::intToString(getID()), oOperations);
+    return getDocument()->getObjects("v_operation", "r_recurrentoperation_id=" + SKGServices::intToString(getID()), oOperations);
 }
 
 SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, const QDate& iDate)
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGRecurrentOperationObject::process", err);
-    oNbInserted=0;
+    oNbInserted = 0;
 
-    if (!hasTimeLimit() || getTimeLimit()>0) {
-        if (isAutoWriteEnabled() || iForce) {
-            QDate nextDate=getDate();
-            if (iDate>=nextDate.addDays(-getAutoWriteDays())) {
+    if(!hasTimeLimit() || getTimeLimit() > 0) {
+        if(isAutoWriteEnabled() || iForce) {
+            QDate nextDate = getDate();
+            if(iDate >= nextDate.addDays(-getAutoWriteDays())) {
                 SKGOperationObject op;
-                err=getParentOperation(op);
-                if (err.isSucceeded()) {
+                err = getParentOperation(op);
+                if(err.isSucceeded()) {
                     //Create the duplicated operation
                     SKGOperationObject newOp;
-                    err=op.duplicate(newOp, nextDate);
+                    err = op.duplicate(newOp, nextDate);
 
-                    if (!op.isTemplate()) {
+                    if(!op.isTemplate()) {
                         //Set old op as recurrent
-                        if (err.isSucceeded()) err=op.setAttribute("r_recurrentoperation_id", SKGServices::intToString(getID()));
-                        if (err.isSucceeded()) err=op.save();
+                        if(err.isSucceeded()) err = op.setAttribute("r_recurrentoperation_id", SKGServices::intToString(getID()));
+                        if(err.isSucceeded()) err = op.save();
 
                         //Set new operation as reference
-                        if (err.isSucceeded()) err=setParentOperation(newOp);
+                        if(err.isSucceeded()) err = setParentOperation(newOp);
                     } else {
                         //Set new op as recurrent
-                        if (err.isSucceeded()) err=newOp.setAttribute("r_recurrentoperation_id", SKGServices::intToString(getID()));
-                        if (err.isSucceeded()) err=newOp.save();
+                        if(err.isSucceeded()) err = newOp.setAttribute("r_recurrentoperation_id", SKGServices::intToString(getID()));
+                        if(err.isSucceeded()) err = newOp.save();
                     }
 
-                    if (err.isSucceeded()) err=setDate(getNextDate());
-                    if (err.isSucceeded() && hasTimeLimit()) err=setTimeLimit(getTimeLimit()-1);
-                    if (err.isSucceeded()) err=save();
-                    if (err.isSucceeded()) err=load();
+                    if(err.isSucceeded()) err = setDate(getNextDate());
+                    if(err.isSucceeded() && hasTimeLimit()) err = setTimeLimit(getTimeLimit() - 1);
+                    if(err.isSucceeded()) err = save();
+                    if(err.isSucceeded()) err = load();
 
                     //Process again in case of multi insert needed
-                    int nbi=0;
-                    if (err.isSucceeded()) err=process(nbi, iForce, iDate);
-                    oNbInserted=oNbInserted+1+nbi;
+                    int nbi = 0;
+                    if(err.isSucceeded()) err = process(nbi, iForce, iDate);
+                    oNbInserted = oNbInserted + 1 + nbi;
 
                     //Send message
-                    if (err.isSucceeded()) err=newOp.load();
-                    if (err.isSucceeded()) {
-                        err=getDocument()->sendMessage(i18nc("An information message", "Operation '%1' has been inserted",newOp.getDisplayName()));
+                    if(err.isSucceeded()) err = newOp.load();
+                    if(err.isSucceeded()) {
+                        err = getDocument()->sendMessage(i18nc("An information message", "Operation '%1' has been inserted", newOp.getDisplayName()));
                     }
                 }
             }
         }
 
-        if (isWarnEnabled() && err.isSucceeded()) {
-            QDate nextDate=getDate();
-            if (QDate::currentDate()>=nextDate.addDays(-getWarnDays())) {
+        if(isWarnEnabled() && err.isSucceeded()) {
+            QDate nextDate = getDate();
+            if(QDate::currentDate() >= nextDate.addDays(-getWarnDays())) {
                 SKGOperationObject op;
-                err=getParentOperation(op);
-                if (err.isSucceeded()) {
-                    int nbdays=QDate::currentDate().daysTo(nextDate);
-                    if (nbdays>0) {
-                        QString objname=op.getDisplayName();
-                        err=getDocument()->sendMessage(i18np("Operation '%2' will be inserted in one day", "Operation '%2' will be inserted in %1 days", nbdays, objname));
+                err = getParentOperation(op);
+                if(err.isSucceeded()) {
+                    int nbdays = QDate::currentDate().daysTo(nextDate);
+                    if(nbdays > 0) {
+                        QString objname = op.getDisplayName();
+                        err = getDocument()->sendMessage(i18np("Operation '%2' will be inserted in one day", "Operation '%2' will be inserted in %1 days", nbdays, objname));
                     }
                 }
             }
@@ -265,21 +263,21 @@ SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, con
     return err;
 }
 
-SKGError SKGRecurrentOperationObject::process(SKGDocument* iDocument, int& oNbInserted, const QDate& iDate)
+SKGError SKGRecurrentOperationObject::process(SKGDocumentBank* iDocument, int& oNbInserted, const QDate& iDate)
 {
     SKGError err;
-    oNbInserted=0;
+    oNbInserted = 0;
 
     //Get all operation with auto_write
     SKGListSKGObjectBase recuOps;
-    err=SKGObjectBase::getObjects(iDocument, "v_recurrentoperation", "", recuOps);
+    if(iDocument) err = iDocument->getObjects("v_recurrentoperation", "", recuOps);
 
-    int nb=recuOps.count();
-    for (int i=0; err.isSucceeded() && i<nb; ++i) {
-        SKGRecurrentOperationObject recu=recuOps.at(i);
-        int nbi=0;
-        err=recu.process(nbi, false, iDate);
-        oNbInserted+=nbi;
+    int nb = recuOps.count();
+    for(int i = 0; err.isSucceeded() && i < nb; ++i) {
+        SKGRecurrentOperationObject recu = recuOps.at(i);
+        int nbi = 0;
+        err = recu.process(nbi, false, iDate);
+        oNbInserted += nbi;
     }
 
     return err;
