@@ -74,7 +74,7 @@ public:
      * @param iDocument the document containing the object
      * @param iID the identifier in @p iTable of the object
      */
-    explicit SKGRuleObject(SKGDocument* iDocument=NULL, int iID=0);
+    explicit SKGRuleObject(SKGDocument* iDocument = NULL, int iID = 0);
 
     /**
      * Copy constructor
@@ -232,7 +232,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError save(bool iInsertOrUpdate=true, bool iReloadAfterSave=true);
+    virtual SKGError save(bool iInsertOrUpdate = true, bool iReloadAfterSave = true);
 
     /**
      * Execute actions
@@ -240,14 +240,14 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError execute(ProcessMode iMode=SKGRuleObject::ALL);
+    virtual SKGError execute(ProcessMode iMode = SKGRuleObject::ALL);
 
     /**
      * Get where clause corresponding to to search condition
      * @param iAdditionalCondition additional select condition
      * @return the where clause
      */
-    virtual QString getSelectSqlOrder(const QString& iAdditionalCondition="") const;
+    virtual QString getSelectSqlOrder(const QString& iAdditionalCondition = "") const;
 
     /**
      * Get alarm info
@@ -261,7 +261,7 @@ public:
      * @param  iType mode
      * @return list of supported operators
      */
-    static QStringList getListOfOperators(SKGServices::AttributeType iAttributeType, SKGRuleObject::ActionType iType=SEARCH);
+    static QStringList getListOfOperators(SKGServices::AttributeType iAttributeType, SKGRuleObject::ActionType iType = SEARCH);
 
     /**
      * Get the NLS display of an operator
@@ -282,10 +282,13 @@ protected:
      * @param iType mode
      * @return the description
      */
-    static QString getDescriptionFromXML(SKGDocument* iDocument, const QString& iXML, bool iSQL=false, SKGRuleObject::ActionType iType=SEARCH);
+    static QString getDescriptionFromXML(SKGDocument* iDocument, const QString& iXML, bool iSQL = false, SKGRuleObject::ActionType iType = SEARCH);
 
 private:
-    static QStringList getFromXML(SKGDocument* iDocument, const QString& iXML, bool iSQL=false, SKGRuleObject::ActionType iType=SEARCH, bool iFullUpdate=false);
+    static QStringList getFromXML(SKGDocument* iDocument, const QString& iXML, bool iSQL = false, SKGRuleObject::ActionType iType = SEARCH, bool iFullUpdate = false);
 };
-
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO(SKGRuleObject, Q_MOVABLE_TYPE);
 #endif
