@@ -34,50 +34,47 @@ SKGTrackerObject::~SKGTrackerObject()
 }
 
 SKGTrackerObject::SKGTrackerObject(const SKGTrackerObject& iObject)
-        :SKGNamedObject(iObject)
+    : SKGNamedObject(iObject)
 {
 }
 
-SKGTrackerObject::SKGTrackerObject ( const SKGObjectBase& iObject )
+SKGTrackerObject::SKGTrackerObject(const SKGObjectBase& iObject)
 
 {
-    if ( iObject.getRealTable() =="refund" ) {
-        copyFrom ( iObject );
+    if(iObject.getRealTable() == "refund") {
+        copyFrom(iObject);
     } else {
-        *this=SKGNamedObject ( iObject.getDocument(), "v_refund", iObject.getID() );
+        *this = SKGNamedObject(iObject.getDocument(), "v_refund", iObject.getID());
     }
 }
 
-const SKGTrackerObject& SKGTrackerObject::operator= (const SKGObjectBase& iObject)
+const SKGTrackerObject& SKGTrackerObject::operator= (const SKGObjectBase & iObject)
 {
     copyFrom(iObject);
     return *this;
 }
 
-SKGError SKGTrackerObject::createTracker ( SKGDocumentBank* iDocument,
+SKGError SKGTrackerObject::createTracker(SKGDocumentBank* iDocument,
         const QString& iName,
         SKGTrackerObject& oTracker,
-        bool iSendPopupMessageOnCreation )
+        bool iSendPopupMessageOnCreation)
 {
     SKGError err;
-    SKGTRACEINRC ( 10, "SKGTrackerObject::createTracker", err );
+    SKGTRACEINRC(10, "SKGTrackerObject::createTracker", err);
 
     //Check if refund is already existing
-    if (iName.isEmpty())
-    {
-        oTracker=SKGTrackerObject(NULL, 0);
-    }
-    else
-    {
-        SKGObjectBase::getObject ( iDocument, "v_refund", "t_name='"+SKGServices::stringToSqlString ( iName ) +'\'', oTracker );
-        if ( oTracker.getID() ==0 ) {
+    if(iName.isEmpty()) {
+        oTracker = SKGTrackerObject(NULL, 0);
+    } else if(iDocument) {
+        iDocument->getObject("v_refund", "t_name='" + SKGServices::stringToSqlString(iName) + '\'', oTracker);
+        if(oTracker.getID() == 0) {
             //No, we have to create it
-            oTracker = SKGTrackerObject ( iDocument );
-            err=oTracker.setName ( iName );
-            if ( err.isSucceeded() ) err=oTracker.save();
+            oTracker = SKGTrackerObject(iDocument);
+            err = oTracker.setName(iName);
+            if(err.isSucceeded()) err = oTracker.save();
 
-            if ( err.isSucceeded() && iSendPopupMessageOnCreation && iDocument ) {
-                err=iDocument->sendMessage (  i18nc( "Information message", "Tracker '%1' has been created" , iName ), true );
+            if(err.isSucceeded() && iSendPopupMessageOnCreation && iDocument) {
+                err = iDocument->sendMessage(i18nc("Information message", "Tracker '%1' has been created" , iName), true);
             }
         }
     }
@@ -87,20 +84,20 @@ SKGError SKGTrackerObject::createTracker ( SKGDocumentBank* iDocument,
 
 SKGError SKGTrackerObject::getSubOperations(SKGListSKGObjectBase& oSubOperations) const
 {
-    SKGError err = getObjects(getDocument(), "v_suboperation",
-                              "r_refund_id="+ SKGServices::intToString(getID()) ,
-                              oSubOperations);
+    SKGError err = getDocument()->getObjects("v_suboperation",
+                   "r_refund_id=" + SKGServices::intToString(getID()) ,
+                   oSubOperations);
     return err;
 }
 
 SKGError SKGTrackerObject::setClosed(bool iClosed)
 {
-    return setAttribute("t_close", iClosed ? "Y" :"N");
+    return setAttribute("t_close", iClosed ? "Y" : "N");
 }
 
 bool SKGTrackerObject::isClosed() const
 {
-    return (getAttribute("t_close")=="Y" ? true : false);
+    return (getAttribute("t_close") == "Y" ? true : false);
 }
 
 SKGError SKGTrackerObject::setComment(const QString& iComment)
