@@ -39,7 +39,7 @@ public:
      * @param iDocument the document containing the object
      * @param iID the identifier in @p iTable of the object
      */
-    explicit SKGTrackerObject(SKGDocument* iDocument=NULL, int iID=0);
+    explicit SKGTrackerObject(SKGDocument* iDocument = NULL, int iID = 0);
 
     /**
      * Copy constructor
@@ -76,7 +76,7 @@ public:
     static SKGError createTracker(SKGDocumentBank* iDocument,
                                   const QString& iName,
                                   SKGTrackerObject& oTracker,
-                                  bool iSendPopupMessageOnCreation=false);
+                                  bool iSendPopupMessageOnCreation = false);
     /**
      * Get all suboperations of this tracker
      * @param oSubOperations all suboperations of this operation
@@ -120,6 +120,9 @@ public:
      */
     virtual double getCurrentAmount() const;
 };
-
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO(SKGTrackerObject, Q_MOVABLE_TYPE);
 
 #endif
