@@ -72,12 +72,12 @@ int main(int argc, char** argv)
         SKGTEST("PROP:getProperty", obj1.getPropertyBlob("ATT1").toInt(), 145);
 
         QStringList oResult;
-        SKGTESTERROR("PROP:getDistinctValues", SKGServices::getDistinctValues(&document1, "parameters", "t_value", "t_value like 'VAL%'", oResult), true);
+        SKGTESTERROR("PROP:getDistinctValues", document1.getDistinctValues("parameters", "t_value", "t_value like 'VAL%'", oResult), true);
         SKGTEST("PROP:oResult.size", oResult.size(), 2);
 
         //delete cascade
         SKGTESTERROR("PROP:Replace", obj1.remove(), true);
-        SKGTESTERROR("PROP:getDistinctValues", SKGServices::getDistinctValues(&document1, "parameters", "t_value", "t_value like 'VAL%'", oResult), true);
+        SKGTESTERROR("PROP:getDistinctValues", document1.getDistinctValues("parameters", "t_value", "t_value like 'VAL%'", oResult), true);
         SKGTEST("PROP:oResult.size", oResult.size(), 1);
     }
 
@@ -86,9 +86,8 @@ int main(int argc, char** argv)
         SKGDocumentBank document1;
         SKGTESTERROR("DOC:initialize", document1.initialize(), true);
         QStringList listTables;
-        SKGTESTERROR("SKGServices::getTablesList", SKGServices::getTablesList(&document1, listTables), true);
-        foreach(const QString& table, listTables)
-        {
+        SKGTESTERROR("DOC::getTablesList", document1.getTablesList(listTables), true);
+        foreach(const QString & table, listTables) {
             document1.getDisplaySchemas(table);
         }
     }
