@@ -23,52 +23,77 @@
  */
 
 #include <kcombobox.h>
-#include <QtDesigner/QDesignerExportWidget>
 #include "skgbasegui_export.h"
 /**
  * This file is a combo box with more features.
  */
 class SKGBASEGUI_EXPORT SKGComboBox : public KComboBox
 {
-        Q_OBJECT
-        /**
-         * Text of the combobox
-         */
-        Q_PROPERTY( QString text READ text WRITE setText USER true)
+    Q_OBJECT
+    /**
+     * Text of the combobox
+     */
+    Q_PROPERTY(QString text READ text WRITE setText USER true)
+    /**
+     * Autocompletion mode
+     */
+    Q_PROPERTY(bool substringCompletionMode READ substringCompletionMode WRITE setSubstringCompletionMode)
 
 public:
-        /**
-         * Default Constructor
-         * @param parent the parent
-         */
-        SKGComboBox(QWidget *parent = 0);
+    /**
+     * Default Constructor
+     * @param parent the parent
+     */
+    SKGComboBox(QWidget *parent = 0);
 
-        /**
-         * Default Destructor
-         */
-        virtual ~SKGComboBox();
+    /**
+     * Default Destructor
+     */
+    virtual ~SKGComboBox();
 
-        /**
-         * Get the text for the combo
-         * @return the text
-         */
-        virtual QString text() const;
+    /**
+     * Get the text for the combo
+     * @return the text
+     */
+    virtual QString text() const;
 
 
-        /**
-         * Set the text for the combo
-         * @param iText the text
-         */
-        virtual void setText (const QString& iText);
+    /**
+     * Set the text for the combo
+     * @param iText the text
+     */
+    virtual void setText(const QString& iText);
 
-        /**
-         * Set the Palette for the combobox.
-         * Reimplemented since the base method does
-         * not apply the Palette to the underlying
-         * QlineEdit
-         * @param palette the new palette
-         */
-        virtual void setPalette (const QPalette& palette);
+    /**
+     * Set the Palette for the combobox.
+     * Reimplemented since the base method does
+     * not apply the Palette to the underlying
+     * QlineEdit
+     * @param palette the new palette
+     */
+    virtual void setPalette(const QPalette& palette);
+
+    /**
+     * "Re-implemented" so that setEditable(true) creates a SKGLineEdit
+     * instead of KLineEdit.
+     */
+    virtual void setEditable(bool editable);
+
+    /**
+     * Get the completion mode
+     * @return the mode
+     */
+    virtual bool substringCompletionMode() const;
+
+
+    /**
+     * Set the completion on substring or not
+     * @param iMode the mode
+     */
+    virtual void setSubstringCompletionMode(bool iMode);
+
+private:
+    bool m_substringCompletionMode;
 };
 
 #endif // SKGCOMBOBOX_H
