@@ -38,9 +38,9 @@ public:
      * @param widget the date picker
      * @param parent the parent
      */
-    SKGDatePickerAction( KDatePicker *widget, QObject *parent )
-            : QWidgetAction( parent ),
-            mDatePicker( widget ), mOriginalParent( widget->parentWidget() ) {
+    SKGDatePickerAction(KDatePicker *widget, QObject *parent)
+        : QWidgetAction(parent),
+          mDatePicker(widget), mOriginalParent(widget->parentWidget()) {
     }
 
 protected:
@@ -50,8 +50,8 @@ protected:
      * @param parent the parent
      * @return the date picker
      */
-    QWidget *createWidget( QWidget *parent ) {
-        mDatePicker->setParent( parent );
+    QWidget *createWidget(QWidget *parent) {
+        mDatePicker->setParent(parent);
         return mDatePicker;
     }
 
@@ -60,12 +60,12 @@ protected:
      * The default implementation hides the widget and schedules it for deletion using QObject::deleteLater().
      * @param widget the widget
      */
-    void deleteWidget( QWidget *widget ) {
-        if ( widget != mDatePicker ) {
+    void deleteWidget(QWidget *widget) {
+        if(widget != mDatePicker) {
             return;
         }
 
-        mDatePicker->setParent( mOriginalParent );
+        mDatePicker->setParent(mOriginalParent);
     }
 
 private:
@@ -73,88 +73,88 @@ private:
     QWidget *mOriginalParent;
 };
 
-SKGDatePickerPopup::SKGDatePickerPopup( Items items, const QDate &date, QWidget *parent )
-        : QMenu( parent )
+SKGDatePickerPopup::SKGDatePickerPopup(Items items, const QDate &date, QWidget *parent)
+    : QMenu(parent)
 {
-    mItems = items;
+    m_items = items;
 
-    mDatePicker = new KDatePicker( this );
-    mDatePicker->setCloseButton( false );
+    m_datePicker = new KDatePicker(this);
+    m_datePicker->setCloseButton(false);
 
-    connect( mDatePicker, SIGNAL( dateEntered( const QDate& ) ), SLOT( slotDateChanged( const QDate& ) ) );
-    connect( mDatePicker, SIGNAL( dateSelected( const QDate& ) ), SLOT( slotDateChanged( const QDate& ) ) );
-    mDatePicker->setDate( date );
+    connect(m_datePicker, SIGNAL(dateEntered(const QDate&)), SLOT(slotDateChanged(const QDate&)));
+    connect(m_datePicker, SIGNAL(dateSelected(const QDate&)), SLOT(slotDateChanged(const QDate&)));
+    m_datePicker->setDate(date);
     buildMenu();
 }
 
 void SKGDatePickerPopup::buildMenu()
 {
-    if ( isVisible() ) return;
+    if(isVisible()) return;
     clear();
 
-    if ( mItems & DatePicker ) {
-        addAction( new SKGDatePickerAction( mDatePicker, this ) );
+    if(m_items & DatePicker) {
+        addAction(new SKGDatePickerAction(m_datePicker, this));
 
-        if ( ( mItems & NoDate ) || ( mItems & Words ) ) {
+        if((m_items & NoDate) || (m_items & Words)) {
             addSeparator();
         }
     }
 
-    if ( mItems & Words ) {
-        addAction( i18nc( "@option today", "Today" ), this, SLOT( slotToday() ) );
-        addAction( i18nc( "@option tomorrow", "Tomorrow" ), this, SLOT( slotTomorrow() ) );
-        addAction( i18nc( "@option next week", "Next Week" ), this, SLOT( slotNextWeek() ) );
-        addAction( i18nc( "@option next month", "Next Month" ), this, SLOT( slotNextMonth() ) );
+    if(m_items & Words) {
+        addAction(i18nc("@option today", "Today"), this, SLOT(slotToday()));
+        addAction(i18nc("@option tomorrow", "Tomorrow"), this, SLOT(slotTomorrow()));
+        addAction(i18nc("@option next week", "Next Week"), this, SLOT(slotNextWeek()));
+        addAction(i18nc("@option next month", "Next Month"), this, SLOT(slotNextMonth()));
 
-        if ( mItems & NoDate ) {
+        if(m_items & NoDate) {
             addSeparator();
         }
     }
 
-    if ( mItems & NoDate ) {
-        addAction( i18nc( "@option do not specify a date", "No Date" ), this, SLOT( slotNoDate() ) );
+    if(m_items & NoDate) {
+        addAction(i18nc("@option do not specify a date", "No Date"), this, SLOT(slotNoDate()));
     }
 }
 
 KDatePicker *SKGDatePickerPopup::datePicker() const
 {
-    return mDatePicker;
+    return m_datePicker;
 }
 
-void SKGDatePickerPopup::setDate( const QDate &date )
+void SKGDatePickerPopup::setDate(const QDate &date)
 {
-    if (mDatePicker) mDatePicker->setDate( date );
+    if(m_datePicker) m_datePicker->setDate(date);
 }
 
-void SKGDatePickerPopup::slotDateChanged( const QDate &date )
+void SKGDatePickerPopup::slotDateChanged(const QDate &date)
 {
-    emit dateChanged( date );
+    Q_EMIT dateChanged(date);
     hide();
 }
 
 void SKGDatePickerPopup::slotToday()
 {
-    emit dateChanged( QDate::currentDate() );
+    Q_EMIT dateChanged(QDate::currentDate());
 }
 
 void SKGDatePickerPopup::slotTomorrow()
 {
-    emit dateChanged( QDate::currentDate().addDays( 1 ) );
+    Q_EMIT dateChanged(QDate::currentDate().addDays(1));
 }
 
 void SKGDatePickerPopup::slotNoDate()
 {
-    emit dateChanged( QDate() );
+    Q_EMIT dateChanged(QDate());
 }
 
 void SKGDatePickerPopup::slotNextWeek()
 {
-    emit dateChanged( QDate::currentDate().addDays( 7 ) );
+    Q_EMIT dateChanged(QDate::currentDate().addDays(7));
 }
 
 void SKGDatePickerPopup::slotNextMonth()
 {
-    emit dateChanged( QDate::currentDate().addMonths( 1 ) );
+    Q_EMIT dateChanged(QDate::currentDate().addMonths(1));
 }
 
 #include "skgdatepickerpopup.moc"
