@@ -22,7 +22,7 @@
 #include "skggraphicsscene.h"
 
 SKGGraphicsScene::SKGGraphicsScene(QObject * iParent)
-        : QGraphicsScene(iParent)
+    : QGraphicsScene(iParent)
 {
 }
 
@@ -30,9 +30,9 @@ SKGGraphicsScene::~SKGGraphicsScene()
 {
 }
 
-void SKGGraphicsScene::mouseDoubleClickEvent ( QGraphicsSceneMouseEvent * mouseEvent )
+void SKGGraphicsScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent * mouseEvent)
 {
-    emit doubleClicked();
+    Q_EMIT doubleClicked();
 
     QGraphicsScene::mouseDoubleClickEvent(mouseEvent);
 }
