@@ -30,36 +30,36 @@
  */
 class SKGBASEGUI_EXPORT SKGGraphicsScene : public QGraphicsScene
 {
-        Q_OBJECT
+    Q_OBJECT
 
 public:
 
-        /**
-         * Default constructor
-         * @param iParent the parent
-         */
-        SKGGraphicsScene(QObject * iParent = 0 );
+    /**
+     * Default constructor
+     * @param iParent the parent
+     */
+    SKGGraphicsScene(QObject * iParent = 0);
 
-        /**
-         * Destructor
-         */
-        virtual ~SKGGraphicsScene();
+    /**
+     * Destructor
+     */
+    virtual ~SKGGraphicsScene();
 
-signals:
-        /**
-         * This signal is launched when a double click is done
-         */
-        void doubleClicked();
+Q_SIGNALS:
+    /**
+     * This signal is launched when a double click is done
+     */
+    void doubleClicked();
 
 protected:
-        /**
-         * This event handler, for event mouseEvent, can be reimplemented in a subclass to receive mouse doubleclick events for the scene.
-         * @param mouseEvent the event
-         */
-        virtual void mouseDoubleClickEvent ( QGraphicsSceneMouseEvent * mouseEvent );
+    /**
+     * This event handler, for event mouseEvent, can be reimplemented in a subclass to receive mouse doubleclick events for the scene.
+     * @param mouseEvent the event
+     */
+    virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent * mouseEvent);
 
 private:
-        Q_DISABLE_COPY(SKGGraphicsScene);
+    Q_DISABLE_COPY(SKGGraphicsScene);
 };
 
 #endif
