@@ -28,7 +28,6 @@
 #include <kglobal.h>
 
 #include <QWidget>
-#include <QtDesigner/QDesignerExportWidget>
 #include <QTimer>
 
 class QGraphicsScene;
@@ -45,17 +44,17 @@ class SKGBASEGUI_EXPORT SKGGraphicsView : public QWidget
     /**
      * State of the view
      */
-    Q_PROPERTY ( QString state READ getState WRITE setState USER true )
+    Q_PROPERTY(QString state READ getState WRITE setState USER true)
     /**
      * To set the toolbar visible or not
      */
-    Q_PROPERTY ( bool toolBarVisible READ isToolBarVisible WRITE setToolBarVisible )
+    Q_PROPERTY(bool m_toolBarVisible READ isToolBarVisible WRITE setToolBarVisible)
 public:
     /**
      * Default Constructor
      * @param parent the parent
      */
-    SKGGraphicsView ( QWidget *parent = 0 );
+    SKGGraphicsView(QWidget *parent = 0);
 
     /**
      * Default Destructor
@@ -66,7 +65,7 @@ public:
      * Set current scene
      * @param iScene The scene
      */
-    virtual void setScene ( QGraphicsScene * iScene );
+    virtual void setScene(QGraphicsScene * iScene);
 
     /**
      * Get the internal Graphic view
@@ -78,7 +77,7 @@ public:
      * Set the visibility of the ToolBar
      * @param iVisibility visibility
      */
-    virtual void setToolBarVisible ( bool iVisibility );
+    virtual void setToolBarVisible(bool iVisibility);
 
     /**
      * Get the visibility of the ToolBar
@@ -86,6 +85,12 @@ public:
      */
     virtual bool isToolBarVisible() const;
 
+    /**
+     * Add a widget in the toolbar
+     * @param iWidget widget
+     */
+    virtual void addToolbarWidget(QWidget* iWidget);
+
     /**
      * Get the current state
      * @return a string containing all information needed to set the same state.
@@ -98,7 +103,7 @@ public:
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState ( const QString& iState );
+    virtual void setState(const QString& iState);
 
     /**
      * Get a pointer on the contextual menu
@@ -106,46 +111,21 @@ public:
      */
     virtual KMenu* getContextualMenu() const;
 
-public slots:
+public Q_SLOTS:
     /**
      * Set the zoom
      */
     virtual void onZoom();
 
-    /**
-     * Zoom in
-     */
-    virtual void onZoomIn();
-
-    /**
-     * Zoom out
-     */
-    virtual void onZoomOut();
-
-    /**
-     * Fit on scene
-     */
-    virtual void onZoomOriginal();
-
     /**
      * Print
      */
     virtual void onPrint();
 
     /**
-     * Export in PDF
+     * Export
      */
-    virtual void onSavePDF();
-
-    /**
-     * Export as images
-     */
-    virtual void onSaveImage();
-
-    /**
-     * Export as SVG
-     */
-    virtual void onSaveSvg();
+    virtual void onExport();
 
     /**
      * Copy
@@ -162,7 +142,12 @@ public slots:
      */
     virtual void onSwitchAntialiasing();
 
-signals:
+    /**
+     * Reinitialize zoom
+     */
+    virtual void initializeZoom();
+
+Q_SIGNALS:
     /**
      * View is resized
      */
@@ -175,23 +160,23 @@ protected:
      * @param event event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter ( QObject *object, QEvent *event );
+    virtual bool eventFilter(QObject *object, QEvent *event);
 
-private slots:
-    void showMenu ( const QPoint& pos );
+private Q_SLOTS:
+    void showMenu(const QPoint& pos);
 
 private:
-    Q_DISABLE_COPY ( SKGGraphicsView );
+    Q_DISABLE_COPY(SKGGraphicsView);
     Ui::skggraphicview_base ui;
 
-    double oscale;
+    double m_oscale;
 
-    KMenu* mainMenu;
-    QAction* actZoomOriginal;
-    QAction* actShowToolBar;
-    QAction* actAntialiasing;
-    bool toolBarVisible;
-    QTimer* timer;
+    KMenu* m_mainMenu;
+    QAction* m_actZoomOriginal;
+    QAction* m_actShowToolBar;
+    QAction* m_actAntialiasing;
+    bool m_toolBarVisible;
+    QTimer m_timer;
 };
 
 #endif // SKGGRAPHICSVIEW_H
