@@ -24,27 +24,24 @@
 #include <QKeyEvent>
 
 SKGTableWidget::SKGTableWidget(QWidget *parent)
-        : QTableWidget(parent)
+    : QTableWidget(parent)
 {
-    this->installEventFilter ( this );
+    this->installEventFilter(this);
 }
 
 SKGTableWidget::~SKGTableWidget()
 {
 }
 
-bool SKGTableWidget::eventFilter ( QObject *object, QEvent *event )
+bool SKGTableWidget::eventFilter(QObject *object, QEvent *event)
 {
-    if (object==this)
-    {
-        QKeyEvent* kevent=dynamic_cast<QKeyEvent*>(event);
-        if (kevent && kevent->key()==Qt::Key_Delete && state()!=QAbstractItemView::EditingState)
-        {
+    if(object == this) {
+        QKeyEvent* kevent = dynamic_cast<QKeyEvent*>(event);
+        if(kevent && kevent->key() == Qt::Key_Delete && state() != QAbstractItemView::EditingState) {
             QList<QTableWidgetItem*> selectedItems = this->selectedItems();
-            if (selectedItems.count() >0)
-            {
-                emit removeSelectedItems();
-                if (event) event->accept();
+            if(selectedItems.count() > 0) {
+                Q_EMIT removeSelectedItems();
+                if(event) event->accept();
                 return true; //stop the process
             }
         }
