@@ -27,74 +27,74 @@
 #include <QtPlugin>
 
 SKGTableWithGraphDesignerPlugin::SKGTableWithGraphDesignerPlugin(QObject *parent)
-                : QObject(parent)
+    : QObject(parent)
 {
-        initialized = false;
+    m_initialized = false;
 }
 
 void SKGTableWithGraphDesignerPlugin::initialize(QDesignerFormEditorInterface * /* core */)
 {
-        if (initialized) return;
+    if(m_initialized) return;
 
-        initialized = true;
+    m_initialized = true;
 }
 
 bool SKGTableWithGraphDesignerPlugin::isInitialized() const
 {
-        return initialized;
+    return m_initialized;
 }
 
 QWidget *SKGTableWithGraphDesignerPlugin::createWidget(QWidget *parent)
 {
-        return new SKGTableWithGraph(parent);
+    return new SKGTableWithGraph(parent);
 }
 
 QString SKGTableWithGraphDesignerPlugin::name() const
 {
-        return "SKGTableWithGraph";
+    return "SKGTableWithGraph";
 }
 
 QString SKGTableWithGraphDesignerPlugin::group() const
 {
-        return "SKG Widgets";
+    return "SKG Widgets";
 }
 
 QIcon SKGTableWithGraphDesignerPlugin::icon() const
 {
-        return KIcon("skg_open");
+    return KIcon("skg_open");
 }
 
 QString SKGTableWithGraphDesignerPlugin::toolTip() const
 {
-        return "A Table with graph";
+    return "A Table with graph";
 }
 
 QString SKGTableWithGraphDesignerPlugin::whatsThis() const
 {
-        return "A Table with graph";
+    return "A Table with graph";
 }
 
 bool SKGTableWithGraphDesignerPlugin::isContainer() const
 {
-        return false;
+    return false;
 }
 
 QString SKGTableWithGraphDesignerPlugin::domXml() const
 {
-        return "<widget class=\"SKGTableWithGraph\" name=\"SKGTableWithGraph\">\n"
-               " <property name=\"geometry\">\n"
-               "  <rect>\n"
-               "   <x>0</x>\n"
-               "   <y>0</y>\n"
-               "   <width>100</width>\n"
-               "   <height>100</height>\n"
-               "  </rect>\n"
-               " </property>\n"
-               "</widget>\n";
+    return "<widget class=\"SKGTableWithGraph\" name=\"SKGTableWithGraph\">\n"
+           " <property name=\"geometry\">\n"
+           "  <rect>\n"
+           "   <x>0</x>\n"
+           "   <y>0</y>\n"
+           "   <width>100</width>\n"
+           "   <height>100</height>\n"
+           "  </rect>\n"
+           " </property>\n"
+           "</widget>\n";
 }
 
 QString SKGTableWithGraphDesignerPlugin::includeFile() const
 {
-        return "skgtablewithgraph.h";
+    return "skgtablewithgraph.h";
 }
 
