@@ -27,74 +27,74 @@
 #include <QtPlugin>
 
 SKGTabWidgetDesignerPlugin::SKGTabWidgetDesignerPlugin(QObject *parent)
-                : QObject(parent)
+    : QObject(parent)
 {
-        initialized = false;
+    m_initialized = false;
 }
 
 void SKGTabWidgetDesignerPlugin::initialize(QDesignerFormEditorInterface * /* core */)
 {
-        if (initialized) return;
+    if(m_initialized) return;
 
-        initialized = true;
+    m_initialized = true;
 }
 
 bool SKGTabWidgetDesignerPlugin::isInitialized() const
 {
-        return initialized;
+    return m_initialized;
 }
 
 QWidget *SKGTabWidgetDesignerPlugin::createWidget(QWidget *parent)
 {
-        return new SKGTabWidget(parent);
+    return new SKGTabWidget(parent);
 }
 
 QString SKGTabWidgetDesignerPlugin::name() const
 {
-        return "SKGTabWidget";
+    return "SKGTabWidget";
 }
 
 QString SKGTabWidgetDesignerPlugin::group() const
 {
-        return "SKG Widgets";
+    return "SKG Widgets";
 }
 
 QIcon SKGTabWidgetDesignerPlugin::icon() const
 {
-	return KIcon("skg_open");
+    return KIcon("skg_open");
 }
 
 QString SKGTabWidgetDesignerPlugin::toolTip() const
 {
-        return "A KTabWidget with more feature";
+    return "A KTabWidget with more feature";
 }
 
 QString SKGTabWidgetDesignerPlugin::whatsThis() const
 {
-        return "A KTabWidget with more feature";
+    return "A KTabWidget with more feature";
 }
 
 bool SKGTabWidgetDesignerPlugin::isContainer() const
 {
-        return false;
+    return false;
 }
 
 QString SKGTabWidgetDesignerPlugin::domXml() const
 {
-        return "<widget class=\"SKGTabWidget\" name=\"SKGTabWidget\">\n"
-               " <property name=\"geometry\">\n"
-               "  <rect>\n"
-               "   <x>0</x>\n"
-               "   <y>0</y>\n"
-               "   <width>100</width>\n"
-               "   <height>100</height>\n"
-               "  </rect>\n"
-               " </property>\n"
-               "</widget>\n";
+    return "<widget class=\"SKGTabWidget\" name=\"SKGTabWidget\">\n"
+           " <property name=\"geometry\">\n"
+           "  <rect>\n"
+           "   <x>0</x>\n"
+           "   <y>0</y>\n"
+           "   <width>100</width>\n"
+           "   <height>100</height>\n"
+           "  </rect>\n"
+           " </property>\n"
+           "</widget>\n";
 }
 
 QString SKGTabWidgetDesignerPlugin::includeFile() const
 {
-        return "skgtabwidget.h";
+    return "skgtabwidget.h";
 }
 
