@@ -27,21 +27,21 @@
 #include <QtPlugin>
 
 SKGZoomSelectorDesignerPlugin::SKGZoomSelectorDesignerPlugin(QObject *parent)
-        : QObject(parent)
+    : QObject(parent)
 {
-    initialized = false;
+    m_initialized = false;
 }
 
 void SKGZoomSelectorDesignerPlugin::initialize(QDesignerFormEditorInterface * /* core */)
 {
-    if (initialized) return;
+    if(m_initialized) return;
 
-    initialized = true;
+    m_initialized = true;
 }
 
 bool SKGZoomSelectorDesignerPlugin::isInitialized() const
 {
-    return initialized;
+    return m_initialized;
 }
 
 QWidget *SKGZoomSelectorDesignerPlugin::createWidget(QWidget *parent)
