@@ -21,15 +21,38 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
+#include "skgbasemodeler_export.h"
 #include "skgdefine.h"
 
 #include <QString>
-#include "skgbasemodeler_export.h"
+#include <QObject>
 /**
 * This class manages errors
 */
-class SKGBASEMODELER_EXPORT SKGError
+class SKGBASEMODELER_EXPORT SKGError : public QObject
 {
+    Q_OBJECT;
+    Q_CLASSINFO("D-Bus Interface", "org.skrooge.SKGError");
+    /**
+     * Return code of the error
+     */
+    Q_PROPERTY(int returnCode READ getReturnCode WRITE setReturnCode);
+    /**
+     * Message of the error
+     */
+    Q_PROPERTY(QString message READ getMessage WRITE setMessage);
+    /**
+     * Full message of the error
+     */
+    Q_PROPERTY(QString message READ getFullMessageWithHistorical);
+    /**
+     * To know if it is a success of the error
+     */
+    Q_PROPERTY(bool succeeded READ isSucceeded);
+    /**
+     * To know if it is a failure of the error
+     */
+    Q_PROPERTY(bool failed READ isFailed);
 public:
     /**
     * Constructor
@@ -148,24 +171,27 @@ public:
     */
     virtual SKGError* getPreviousError() const;
 
-protected:
+private:
     /**
     * the return code of the error
     *         0 : It's not an error (SUCCEEDED)
     *         <0: It's just a warning (SUCCEEDED)
     *         >0: It's not error (FAILED)
     */
-    int rc;
+    int m_rc;
 
     /**
      * the message of the error
      */
-    QString message;
+    QString m_message;
 
     /**
      * the previous error on this branch
      */
-    SKGError* previousError;
+    SKGError* m_previousError;
 };
-
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO(SKGError, Q_MOVABLE_TYPE);
 #endif //SKGERROR_H
