@@ -17,7 +17,7 @@
 #ifndef SKGSERVICES_H
 #define SKGSERVICES_H
 /** @file
- * This file defines classes SKGDocument.
+ * This file defines classes SKGServices.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -32,7 +32,7 @@
 #include <QIcon>
 
 /**
- * @def SQLLITEERROR
+ * @var SQLLITEERROR
  * Must be used to generate a SKGError on an error coming from sqlite's API
  * Example of usage:
  * @code
@@ -42,10 +42,9 @@
  * @endcode
 
  */
-#define SQLLITEERROR 10000
+static const int SQLLITEERROR = 10000;
 
 class QSqlDatabase;
-class SKGDocument;
 class QTextStream;
 class QDomDocument;
 
@@ -121,28 +120,28 @@ public:
      * This structure defines attributes types
      */
     enum AttributeType {
-        TEXT, 		/**< Text */
-        INTEGER, 	/**< Integer */
-        FLOAT, 		/**< Float */
-        DATE, 		/**< Date */
-        ID, 		/**< Unique identifier */
-        LINK, 		/**< Link */
-        BLOB, 		/**< Blob */
-        BOOL, 		/**< Boolean (Y, N) */
-        TRISTATE,	/**< Tri-state (N, P, C) */
-        OTHER	        /**< Other or undefined */
+        TEXT,       /**< Text */
+        INTEGER,    /**< Integer */
+        FLOAT,      /**< Float */
+        DATE,       /**< Date */
+        ID,         /**< Unique identifier */
+        LINK,       /**< Link */
+        BLOB,       /**< Blob */
+        BOOL,       /**< Boolean (Y, N) */
+        TRISTATE,   /**< Tri-state (N, P, C) */
+        OTHER           /**< Other or undefined */
     };
 
     /**
      * Describe an attribute
      */
     struct SKGAttributeInfo {
-        QString name; 			/**< The internal name of the attribute */
-        QString display; 		/**< The name for display of the attribute */
-        QIcon icon; 		        /**< The icon for display of the attribute */
-        AttributeType type; 		/**< The type of the attribute */
-        bool notnull; 			/**< To know if the attribute can be null or not */
-        QString defaultvalue; 		/**< The default value of the attribute */
+        QString name;           /**< The internal name of the attribute */
+        QString display;        /**< The name for display of the attribute */
+        QIcon icon;                 /**< The icon for display of the attribute */
+        AttributeType type;         /**< The type of the attribute */
+        bool notnull;           /**< To know if the attribute can be null or not */
+        QString defaultvalue;       /**< The default value of the attribute */
     } ;
 
     /**
@@ -197,7 +196,7 @@ public:
      * @param iSeparator the separator
      * @return the converted csv string
      */
-    static QString stringsToCsv(const QStringList& iList, const QChar& iSeparator=';');
+    static QString stringsToCsv(const QStringList& iList, const QChar& iSeparator = ';');
 
     /**
      * Convert a QString to a html QString
@@ -229,12 +228,20 @@ public:
 
     /**
      * Convert a QDateTime into a QString ready for sql order.
-    * The output format is "%Y-%m-%d %H-%M-%S"
-    * @param iDateTime the time
-    * @return the converted QString
-    */
+     * The output format is "%Y-%m-%d %H-%M-%S"
+     * @param iDateTime the time
+     * @return the converted QString
+     */
     static QString timeToString(const QDateTime& iDateTime);
 
+    /**
+     * Compute the number of working days between two dates.
+     * @param iFrom first date
+     * @param iTo seconde date
+     * @return the number of working days.
+     */
+    static int nbWorkingDays(const QDate& iFrom, const QDate& iTo);
+
     /**
      * Convert a QString to QDateTime.
      * @param iDateString the time. The format must be "%Y-%m-%d %H-%M-%S" or "%Y-%m-%d"
@@ -284,7 +291,7 @@ public:
      * @param oRealSeparator the real csv separator. If the csv string is strictly all enclosed then oRealSeparator will contain the real separator
      * @return the list of all values in this csv line
      */
-    static QStringList splitCSVLine(const QString& iString, const QChar& iSeparator=';', bool iCoteDefineBlock=true, QChar* oRealSeparator=NULL);
+    static QStringList splitCSVLine(const QString& iString, const QChar& iSeparator = ';', bool iCoteDefineBlock = true, QChar* oRealSeparator = NULL);
 
     /**
      * To dump a table
@@ -292,7 +299,7 @@ public:
      * @param iMode dump mode
      * @return the dump of the table
      */
-    static QStringList tableToDump(const SKGStringListList& iTable, DumpMode iMode);
+    static QStringList tableToDump(const SKGStringListList& iTable, SKGServices::DumpMode iMode);
 
     /**
      * Get the table name corresponding to a table or a view
@@ -324,34 +331,23 @@ public:
     static SKGError copySqliteDatabaseToXml(QSqlDatabase* iDb, QDomDocument& oDocument);
 
     /**
-     * Execute a sqlite order
-     * @param iDocument the SKGDocument document
-     * @param iSqlOrder the sql order
-     * @param iLastId to retrieve the id of the lest created object
+     * Execute a sqlite orders
+     * @param iDb a database pointer
+     * @param iSqlOrders the sql orders
      * @return An object managing the error
      *   @see SKGError
      */
-    static SKGError executeSqliteOrder(SKGDocument* iDocument, const QString& iSqlOrder, int* iLastId=NULL);
+    static SKGError executeSqliteOrders(QSqlDatabase* iDb, const QStringList& iSqlOrders);
 
     /**
      * Execute a sqlite order
      * @param iDb a database pointer
      * @param iSqlOrder the sql order
-     * @param iLastId to retrieve the id of the lest created object
+     * @param iLastId to retrieve the id of the last created object
      * @return An object managing the error
      *   @see SKGError
      */
-    static SKGError executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, int* iLastId=NULL);
-
-    /**
-    * Execute a select sqlite order and return the result in @p oResult
-    * @param iDocument the SKGDocument document
-    * @param iSqlOrder the sql order
-    * @param oResult the result of the select. It's a vector of vector of QString
-    * @return An object managing the error
-    *   @see SKGError
-    */
-    static SKGError executeSelectSqliteOrder(SKGDocument* iDocument, const QString& iSqlOrder, SKGStringListList& oResult);
+    static SKGError executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, int* iLastId = NULL);
 
     /**
     * Execute a select sqlite order and return the result in @p oResult
@@ -363,17 +359,6 @@ public:
     */
     static SKGError executeSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, SKGStringListList& oResult);
 
-    /**
-    * dump a select sqlite order
-    * @param iDocument the SKGDocument document
-    * @param iSqlOrder the sql order
-    * @param oStream the output stream, NULL for std output (cout)
-    * @param iMode dump mode
-    * @return An object managing the error
-    *   @see SKGError
-    */
-    static SKGError dumpSelectSqliteOrder(SKGDocument* iDocument, const QString& iSqlOrder, QTextStream* oStream=NULL, DumpMode iMode=DUMP_TEXT);
-
     /**
     * dump a select sqlite order
     * @param iDb A database pointer
@@ -383,17 +368,7 @@ public:
     * @return An object managing the error
     *   @see SKGError
     */
-    static SKGError dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, QTextStream* oStream=NULL, DumpMode iMode=DUMP_TEXT);
-    /**
-     * dump a select sqlite order
-     * @param iDocument the SKGDocument document
-     * @param iSqlOrder the sql order
-     * @param oResult the output
-     * @param iMode dump mode
-     * @return An object managing the error
-     *   @see SKGError
-     */
-    static SKGError dumpSelectSqliteOrder(SKGDocument* iDocument, const QString& iSqlOrder, QString& oResult, DumpMode iMode=DUMP_TEXT);
+    static SKGError dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, QTextStream* oStream = NULL, SKGServices::DumpMode iMode = DUMP_TEXT);
 
     /**
      * dump a select sqlite order
@@ -404,18 +379,7 @@ public:
      * @return An object managing the error
      *   @see SKGError
      */
-    static SKGError dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, QString& oResult, DumpMode iMode=DUMP_TEXT);
-
-    /**
-     * dump a select sqlite order
-     * @param iDocument the SKGDocument document
-     * @param iSqlOrder the sql order
-     * @param oResult the output
-     * @param iMode dump mode
-     * @return An object managing the error
-     *   @see SKGError
-     */
-    static SKGError dumpSelectSqliteOrder(SKGDocument* iDocument, const QString& iSqlOrder, QStringList& oResult, DumpMode iMode=DUMP_TEXT);
+    static SKGError dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, QString& oResult, SKGServices::DumpMode iMode = DUMP_TEXT);
 
     /**
      * dump a select sqlite order
@@ -426,59 +390,7 @@ public:
      * @return An object managing the error
      *   @see SKGError
      */
-    static SKGError dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, QStringList& oResult, DumpMode iMode=DUMP_TEXT);
-
-    /**
-     * Retrieve all distinct values of an attribute of a table
-     * @param iDocument the document where to look for
-     * @param iTable the table where to look for
-     * @param iAttribute the attribute wanted (only one)
-     * @param iWhereClause a whereclause
-     * @param oResult the output result
-     * @return An object managing the error
-     *   @see SKGError
-     */
-    static SKGError getDistinctValues(SKGDocument* iDocument, const QString& iTable, const QString& iAttribute, const QString& iWhereClause, QStringList& oResult);
-
-    /**
-     * Retrieve all distinct values of an attribute of a table
-     * @param iDocument the document where to look for
-     * @param iTable the table where to look for
-     * @param iAttribute the attribute wanted (only one)
-     * @param oResult the output result
-     * @return An object managing the error
-     *   @see SKGError
-     */
-    static SKGError getDistinctValues(SKGDocument* iDocument, const QString& iTable, const QString& iAttribute, QStringList& oResult);
-
-    /**
-     * Retrieve description of each attribute of a table
-     * @param iDocument the document where to look for
-     * @param iTable the table where to look for
-     * @param oResult the output result
-     * @return An object managing the error
-     *   @see SKGError
-     */
-    static SKGError getAttributesDescription(SKGDocument* iDocument, const QString& iTable, SKGAttributesList& oResult);
-
-    /**
-     * Retrieve list of attributes
-     * @param iDocument the document where to look for
-     * @param iTable the table where to look for
-     * @param oResult the output result
-     * @return An object managing the error
-     *   @see SKGError
-     */
-    static SKGError getAttributesList(SKGDocument* iDocument, const QString& iTable, QStringList& oResult);
-
-    /**
-     * Retrieve list of tables
-     * @param iDocument the document where to look for
-     * @param oResult the output result
-     * @return An object managing the error
-     *   @see SKGError
-     */
-    static SKGError getTablesList(SKGDocument* iDocument, QStringList& oResult);
+    static SKGError dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, QStringList& oResult, SKGServices::DumpMode iMode = DUMP_TEXT);
 
     /**
      * Return the current time in millisecond
@@ -497,7 +409,7 @@ public:
      *   @see SKGError
      */
     static SKGError cryptFile(const QString& iFileSource, const QString& iFileTarget,
-                              const QString& iPassword, bool iEncrypt=true, const QString& iHeaderFile="");
+                              const QString& iPassword, bool iEncrypt = true, const QString& iHeaderFile = "");
 
     /**
      * To enable, disable sql traces
@@ -506,6 +418,6 @@ public:
 
 private:
     Q_DISABLE_COPY(SKGServices);
-    static SKGError lastCallbackError;
+    static SKGError m_lastCallbackError;
 };
 #endif
