@@ -91,30 +91,30 @@ class SKGDocument;
 class SKGBASEMODELER_EXPORT SKGTransactionMng
 {
 public:
-        /**
-         * Constructor.
-         * This class must be used with the macro
-         * @see SKGBEGINTRANSACTION
-         * @param iDocument The parent document of the transaction
-         * @param iName The message of the transaction
-         * @param iError A pointer of the error object of the calling scope
-         * @param iNbStep the number of step in this transaction.
-         * It's used to call the progress callback.
-         * @see The SKGError
-         */
-        SKGTransactionMng(const SKGDocument* iDocument, const QString& iName, SKGError* iError, int iNbStep=0);
+    /**
+     * Constructor.
+     * This class must be used with the macro
+     * @see SKGBEGINTRANSACTION
+     * @param iDocument The parent document of the transaction
+     * @param iName The message of the transaction
+     * @param iError A pointer of the error object of the calling scope
+     * @param iNbStep the number of step in this transaction.
+     * It's used to call the progress callback.
+     * @see The SKGError
+     */
+    SKGTransactionMng(SKGDocument* iDocument, const QString& iName, SKGError* iError, int iNbStep = 1);
 
-        /**
-         * Destructor
-         */
-        virtual ~SKGTransactionMng();
+    /**
+     * Destructor
+     */
+    virtual ~SKGTransactionMng();
 
 private:
-        Q_DISABLE_COPY(SKGTransactionMng);
+    Q_DISABLE_COPY(SKGTransactionMng);
 
-        SKGError* error;
-        SKGDocument* parentDocument;
-        bool errorInBeginTransaction;
+    SKGError* m_error;
+    SKGDocument* m_parentDocument;
+    bool m_errorInBeginTransaction;
 };
 
 #endif
