@@ -37,43 +37,21 @@ public:
     /**
      * Default Constructor
      */
-    SKGBankBoardWidget (SKGDocument* iDocument );
+    SKGBankBoardWidget(SKGDocument* iDocument);
 
     /**
      * Default Destructor
      */
     virtual ~SKGBankBoardWidget();
 
-    /**
-     * Get the current state
-     * MUST BE OVERWRITTEN
-     * @return a string containing all information needed to set the same state.
-     * Could be an XML stream
-     */
-    virtual QString getState();
-
-    /**
-     * Set the current state
-     * MUST BE OVERWRITTEN
-     * @param iState must be interpreted to set the state of the widget
-     */
-    virtual void setState(const QString& iState);
-
-private slots:
-    void dataModified(const QString& iTableName="", int iIdTransaction=0);
+private Q_SLOTS:
+    void dataModified(const QString& iTableName = "", int iIdTransaction = 0);
     void onOpen(const QString& iLink);
 
 private:
-    Q_DISABLE_COPY ( SKGBankBoardWidget );
+    Q_DISABLE_COPY(SKGBankBoardWidget);
 
-    Ui::skgbankplugin_board ui;;
-
-    KAction* menuAssets;
-    KAction* menuCurrent;
-    KAction* menuCreditCard;
-    KAction* menuInvestment;
-    KAction* menuOther;
-    KAction* menuFavorite;
+    Ui::skgbankplugin_board ui;
 };
 
-#endif // SKGDEBUGPLUGIN_H
+#endif // SKGBANKBOARDWIDGET_H
