@@ -35,7 +35,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGBookmarkBoardWidget (SKGDocument* iDocument );
+    SKGBookmarkBoardWidget(SKGDocument* iDocument);
 
     /**
      * Default Destructor
@@ -57,14 +57,15 @@ public:
      */
     virtual void setState(const QString& iState);
 
-private slots:
+private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction);
     void onOpen(const QString& iLink);
+    void onOpen();
 
 private:
-    Q_DISABLE_COPY ( SKGBookmarkBoardWidget );
+    Q_DISABLE_COPY(SKGBookmarkBoardWidget);
 
-    Ui::skgbookmarkboardwidget ui;;
+    Ui::skgbookmarkboardwidget ui;
 };
 
 #endif // SKGBOOKMARKBOARDWIDGET_H
