@@ -35,7 +35,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGScheduledBoardWidget (SKGDocument* iDocument );
+    SKGScheduledBoardWidget(SKGDocument* iDocument);
 
     /**
      * Default Destructor
@@ -57,14 +57,14 @@ public:
      */
     virtual void setState(const QString& iState);
 
-private slots:
+private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction);
     void onOpen(const QString& iLink);
 
 private:
-    Q_DISABLE_COPY ( SKGScheduledBoardWidget );
+    Q_DISABLE_COPY(SKGScheduledBoardWidget);
 
-    Ui::skgscheduledplugin_board ui;;
+    Ui::skgscheduledplugin_board ui;
 };
 
 #endif // SKGSCHEDULEDBOARDWIDGET_H
