@@ -44,18 +44,6 @@ public:
      */
     virtual ~SKGScheduledPluginWidget();
 
-    /**
-     * Get the current selection
-     * @return selected objects
-     */
-    virtual SKGObjectBase::SKGListSKGObjectBase getSelectedObjects();
-
-    /**
-     * Get the number of seleted object
-     * @return number of selected objects
-     */
-    virtual int getNbSelectedObjects();
-
     /**
      * Get the current state
      * MUST BE OVERWRITTEN
@@ -79,17 +67,10 @@ public:
     virtual QString getDefaultStateAttribute();
 
     /**
-     * Get the widget must be printed
+     * Get the main widget
      * @return a widget
      */
-    virtual QWidget* getWidgetForPrint();
-
-    /**
-     * Get the zoomable widget. MUST BE OVERWRITTEN
-     * By Overwritting this function, you don't have to implement following ones.
-     * @return the tree view.
-     */
-    virtual QWidget* zoomableWidget() const;
+    virtual QWidget* mainWidget() const;
 
 protected:
     /**
@@ -98,10 +79,9 @@ protected:
      * @param event event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter ( QObject *object, QEvent *event );
+    virtual bool eventFilter(QObject *object, QEvent *event);
 
-private slots:
-    void dataModified(const QString& iTableName, int iIdTransaction);
+private Q_SLOTS:
     void onSelectionChanged();
     void onDoubleClick();
     void onUpdate();
