@@ -37,7 +37,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGAlarmBoardWidget (SKGDocument* iDocument );
+    SKGAlarmBoardWidget(SKGDocument* iDocument);
 
     /**
      * Default Destructor
@@ -59,16 +59,16 @@ public:
      */
     virtual void setState(const QString& iState);
 
-private slots:
-    void dataModified(const QString& iTableName="", int iIdTransaction=0);
-    void onOpen(const QString& iLink="___");
+private Q_SLOTS:
+    void dataModified(const QString& iTableName = "", int iIdTransaction = 0);
+    void onOpen(const QString& iLink = "___");
 
 private:
-    Q_DISABLE_COPY ( SKGAlarmBoardWidget );
+    Q_DISABLE_COPY(SKGAlarmBoardWidget);
 
-    Ui::skgalarmplugin_board ui;;
+    Ui::skgalarmplugin_board ui;
 
-    KAction* menuFavorite;
+    KAction* m_menuFavorite;
 };
 
 #endif // SKGALARMBOARDWIDGET_H
