@@ -24,8 +24,6 @@
 #include "ui_skgtrackerpluginwidget_base.h"
 #include "skgtabpage.h"
 
-class SKGObjectModel;
-
 /**
  * A skrooge plugin to track operations
  */
@@ -67,22 +65,10 @@ public:
     virtual QString getDefaultStateAttribute();
 
     /**
-     * Get the widget must be printed
+     * Get the main widget
      * @return a widget
      */
-    virtual QWidget* getWidgetForPrint();
-
-    /**
-     * Get the current selection
-     * @return selected objects
-     */
-    virtual SKGObjectBase::SKGListSKGObjectBase getSelectedObjects();
-
-    /**
-     * Get the number of seleted object
-     * @return number of selected objects
-     */
-    virtual int getNbSelectedObjects();
+    virtual QWidget* mainWidget() const;
 
     /**
      * To know if this page contains an editor. MUST BE OVERWRITTEN
@@ -95,13 +81,6 @@ public:
      */
     virtual void activateEditor();
 
-    /**
-     * Get the zoomable widget. MUST BE OVERWRITTEN
-     * By Overwritting this function, you don't have to implement following ones.
-     * @return the tree view.
-     */
-    virtual QWidget* zoomableWidget() const;
-
 protected:
     /**
      * Event filtering
@@ -109,23 +88,21 @@ protected:
      * @param event event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter ( QObject *object, QEvent *event );
+    virtual bool eventFilter(QObject *object, QEvent *event);
 
-private slots:
+private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction);
     void onDoubleClick();
     void onSelectionChanged();
     void onEditorModified();
     void onAddTracker();
     void onModifyTracker();
-    void onFilterChanged();
     void cleanEditor();
 
 private:
     Q_DISABLE_COPY(SKGTrackerPluginWidget);
 
     Ui::skgtrackerplugin_base ui;
-    SKGObjectModel* objectModel;
 };
 
 #endif // SKGTRACKERPLUGINWIDGET_H
