@@ -37,7 +37,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGUnitBoardWidget (SKGDocument* iDocument );
+    SKGUnitBoardWidget(SKGDocument* iDocument);
 
     /**
      * Default Destructor
@@ -59,18 +59,18 @@ public:
      */
     virtual void setState(const QString& iState);
 
-private slots:
-    void dataModified(const QString& iTableName="", int iIdTransaction=0);
+private Q_SLOTS:
+    void dataModified(const QString& iTableName = "", int iIdTransaction = 0);
     void onOpen(const QString& iLink);
 
 private:
-    Q_DISABLE_COPY ( SKGUnitBoardWidget );
+    Q_DISABLE_COPY(SKGUnitBoardWidget);
 
-    Ui::skgunitplugin_board ui;;
+    Ui::skgunitplugin_board ui;
 
-    KAction* menuIndexes;
-    KAction* menuShares;
-    KAction* menuSharesOwnedOnly;
+    KAction* m_menuIndexes;
+    KAction* m_menuShares;
+    KAction* m_menuSharesOwnedOnly;
 };
 
 #endif // SKGUNITBOARDWIDGET_H
