@@ -5,10 +5,10 @@ def initSimple():
     waitForObject(":Tip of the Day – Skrooge.Close_KPushButton")
     clickButton(":Tip of the Day – Skrooge.Close_KPushButton")
     waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
-    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
-    sendEvent("QMoveEvent", ":Untitled [modified] - skrooge_SKGMainPanel", -4, -4, 1506, 17)
-    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
-    sendEvent("QResizeEvent", ":Untitled [modified] - skrooge_SKGMainPanel", 1680, 991, 1506, 17)
+#    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
+#    sendEvent("QMoveEvent", ":Untitled [modified] - skrooge_SKGMainPanel", -4, -4, 1506, 17)
+#    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
+#    sendEvent("QResizeEvent", ":Untitled [modified] - skrooge_SKGMainPanel", 1680, 991, 1506, 17)
     waitForObject(":Untitled [modified] - skrooge_KTabBar")
     type(":Untitled [modified] - skrooge_KTabBar", "<Ctrl+W>")
 #    waitForObject(":Bookmark has been modified - Skrooge.Do not ask again_QCheckBox")
@@ -16,6 +16,19 @@ def initSimple():
 #    waitForObject(":Bookmark has been modified - Skrooge.No_KPushButton")
 #    clickButton(":Bookmark has been modified - Skrooge.No_KPushButton")
 
+def initAdvice():
+    initSimple();
+    waitForObject(":Untitled - skrooge_KTabBar")
+    type(":Untitled - skrooge_KTabBar", "<Ctrl+O>")
+    waitForObject(":Question – Skrooge.Do not save_KPushButton")
+    clickButton(":Question – Skrooge.Do not save_KPushButton")
+    waitForObject(":Name:_KUrlComboBox")
+    mouseClick(":Name:_KUrlComboBox", 89, 5, 0, Qt.LeftButton)
+    waitForObject(":Name:_KUrlComboBox")
+    type(":Name:_KUrlComboBox", os.getenv('IN')+"advices.skg")
+    waitForObject(":Name:_KUrlComboBox")
+    type(":Name:_KUrlComboBox", "<Return>")
+    
 def initAllPlugins():
     initSimple();
     waitForObject(":Untitled - skrooge_KTabBar")
@@ -35,28 +48,53 @@ def initAllPluginsAndOpenAllPages():
     waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
     type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+1>")
     waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
+    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")    
+    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
     type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+2>")
     waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
+    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")    
+    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
     type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+3>")
     waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
+    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")    
+    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
     type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+4>")
     waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
+    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")    
+    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
     type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+5>")
     waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
+    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")    
+    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
     type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+6>")
     waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
+    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")    
+    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
     type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+7>")
     waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
+    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")    
+    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
     type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+8>")
     waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
+    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")    
+    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
     type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+9>")
     waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
+    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")    
+    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
     type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Alt+0>")
     waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
+    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")    
+    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
     type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Alt+1>")
     waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
+    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")    
+    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
     type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Alt+2>")
-
+    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
+    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Shift+W>")      
+    waitForObject(":all_plugins.skg [modified] - skrooge_KTabBar")
+    type(":all_plugins.skg [modified] - skrooge_KTabBar", "<Ctrl+Alt+3>")
 
 def bookmarkAndRemoveCurrentPage():
     waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
